import { languages, IEvent } from './fillers/monaco-editor-core';
interface ILang extends languages.ILanguageExtensionPoint {
    loader: () => Promise<ILangImpl>;
}
interface ILangImpl {
    conf: languages.LanguageConfiguration;
    language: languages.IMonarchLanguage;
}
export declare function loadLanguage(languageId: string): Promise<ILangImpl>;
export declare function registerLanguage(def: ILang): void;
export interface ICreateData {
    languageId: string;
}
export interface ModeConfiguration {
    /**
     * Defines whether the built-in completionItemProvider is enabled.
     */
    readonly completionItems?: boolean;
    /**
     * Defines whether the built-in hoverProvider is enabled.
     */
    readonly hovers?: boolean;
    /**
     * Defines whether the built-in documentSymbolProvider is enabled.
     */
    readonly documentSymbols?: boolean;
    /**
     * Defines whether the built-in definitions provider is enabled.
     */
    readonly definitions?: boolean;
    /**
     * Defines whether the built-in references provider is enabled.
     */
    readonly references?: boolean;
    /**
     * Defines whether the built-in references provider is enabled.
     */
    readonly documentHighlights?: boolean;
    /**
     * Defines whether the built-in rename provider is enabled.
     */
    readonly rename?: boolean;
    /**
     * Defines whether the built-in color provider is enabled.
     */
    readonly colors?: boolean;
    /**
     * Defines whether the built-in foldingRange provider is enabled.
     */
    readonly foldingRanges?: boolean;
    /**
     * Defines whether the built-in diagnostic provider is enabled.
     */
    readonly diagnostics?: boolean;
    /**
     * Defines whether the built-in selection range provider is enabled.
     */
    readonly selectionRanges?: boolean;
}
export interface DiagnosticsOptions {
    readonly validate?: boolean;
}
export interface LanguageServiceDefaults {
    readonly languageId: string;
    readonly onDidChange: IEvent<LanguageServiceDefaults>;
    readonly diagnosticsOptions: DiagnosticsOptions;
    readonly modeConfiguration: ModeConfiguration;
    setDiagnosticsOptions(options: DiagnosticsOptions): void;
    setModeConfiguration(modeConfiguration: ModeConfiguration): void;
}
export declare class LanguageServiceDefaultsImpl implements LanguageServiceDefaults {
    private _onDidChange;
    private _diagnosticsOptions;
    private _modeConfiguration;
    private _languageId;
    constructor(languageId: string, diagnosticsOptions: DiagnosticsOptions, modeConfiguration: ModeConfiguration);
    get onDidChange(): IEvent<LanguageServiceDefaults>;
    get languageId(): string;
    get modeConfiguration(): ModeConfiguration;
    get diagnosticsOptions(): DiagnosticsOptions;
    setDiagnosticsOptions(options: DiagnosticsOptions): void;
    setModeConfiguration(modeConfiguration: ModeConfiguration): void;
}
export declare const modeConfigurationDefault: Required<ModeConfiguration>;
export declare const diagnosticDefault: Required<DiagnosticsOptions>;
export declare function debounce(func: Function, timeout: number, immediate?: boolean): (...args: any) => void;
export {};
