import { WorkerManager } from './workerManager';
import * as languageFeatures from './languageFeatures';
export function setupLanguageMode(defaults) {
    const disposables = [];
    const providers = [];
    const client = new WorkerManager(defaults);
    disposables.push(client);
    const worker = (...uris) => {
        return client.getLanguageServiceWorker(...uris);
    };
    function registerProviders() {
        const { languageId, modeConfiguration } = defaults;
        disposeAll(providers);
        if (modeConfiguration.diagnostics) {
            providers.push(new languageFeatures.DiagnosticsAdapter(languageId, worker, defaults));
        }
    }
    registerProviders();
    disposables.push(asDisposable(providers));
    return asDisposable(disposables);
}
function asDisposable(disposables) {
    return { dispose: () => disposeAll(disposables) };
}
function disposeAll(disposables) {
    var _a;
    while (disposables.length) {
        (_a = disposables.pop()) === null || _a === void 0 ? void 0 : _a.dispose();
    }
}
